/* Copyright (C) 2004 Bart
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include "../include/Win_GParted.h"
#include "../include/Utils.h"

#include <gtkmm/messagedialog.h>
#include <gtkmm/main.h>

int main( int argc, char *argv[] )
{
	int installer_mode = false;
	std::vector<Glib::ustring> filesystem_override_opts;

	//initialize thread system
	Glib::thread_init() ;
		 
	//i18n
	bindtextdomain( GETTEXT_PACKAGE, GNOMELOCALEDIR ) ;
	bind_textdomain_codeset( GETTEXT_PACKAGE, "UTF-8" ) ;
	textdomain( GETTEXT_PACKAGE ) ;

	Glib::OptionEntry installer_entry;
	installer_entry.set_long_name( "installer" );
	installer_entry.set_description( "Run in installer mode" );
	installer_entry.set_arg_description( "WID" );
	Glib::OptionEntry filesystem_entry;
	filesystem_entry.set_long_name( "filesystem" );
	filesystem_entry.set_description( "Override filesystem (installer mode only)" );
	filesystem_entry.set_arg_description( "PARTITION:FS" );

	Glib::OptionGroup options( "", "" );
	options.add_entry( installer_entry, installer_mode );
	options.add_entry( filesystem_entry, filesystem_override_opts );

	Glib::OptionContext context;
	context.set_main_group( options );

	Gtk::Main kit( argc, argv, context ) ;

	//check UID
	if ( getuid() != 0 )
	{
		Gtk::MessageDialog dialog( _("Root privileges are required for running GParted"), 
					   false,
					   Gtk::MESSAGE_ERROR,
					   Gtk::BUTTONS_OK ) ;
		dialog .set_secondary_text(
				_("Since GParted can be a weapon of mass destruction only root may run it.") ) ;
		
		dialog .run() ;
		exit( 0 ) ;
	}

	std::vector<Glib::ustring>::iterator iter;
	std::map<Glib::ustring, GParted::FILESYSTEM> filesystem_overrides;
	for ( std::vector<Glib::ustring>::iterator iter = filesystem_override_opts .begin() ;
	      iter != filesystem_override_opts .end() ; ++iter )
	{
		unsigned int index = iter ->find( ':' );
		if (index < iter ->length() )
			filesystem_overrides[iter ->substr( 0, index )] =
				GParted::Utils::get_filesystem_by_name( iter ->substr( index + 1 ) );
	}

	//deal with arguments..
	std::vector<Glib::ustring> user_devices ;
	
	for ( int t = 1 ; t < argc ; t++ )
		user_devices .push_back( argv[ t ] ) ;
	
	GParted::Win_GParted win_gparted( user_devices, installer_mode,
					  filesystem_overrides ) ; 
	if ( !installer_mode )
		win_gparted .show( ) ;
	Gtk::Main::run( ) ;

	return 0 ;
}


